nonebot-plugin-bilibilibot
==========================

简介
======================
基于Nonebot2的bilibili通知插件，可将up主，主播以及番剧的更新/直播动态推送到QQ

特色功能
===============
    - 可通过在B站客户端分享用户主页进行关注up主

    - 可通过在B站客户端分享直播间进行关注主播

    - 可通过分享番剧播放页面进行关注番剧

    - 超级用户可对普通用户进行广播

配置项
============
配置方式: 请在nonebot的全局配置文件中添加如下配置项。

SUPERUSERS
-----------------
    - 类型: List[str]
    - 说明: 超级用户的列表
    - SUPERSUSERS = ["your qq id"]

